@@ -817,10 +817,11 @@ impl Default for Settings {
 
 /// A sensor sample from the BME280.
 #[derive(Debug, Clone, Copy)]
+#[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct Sample {
     /// Temperature reading in celsius.
     pub temperature: f32,
-    /// Pressure reading in kilo-pascals.
+    /// Pressure reading in pascal.
     pub pressure: f32,
     /// Humidity in perfect relative.
     pub humidity: f32,
